@@ -72,11 +72,13 @@ class DataNodeConfig(Section):
 
     _EXPOSED_TYPE_KEY = "exposed_type"
     _EXPOSED_TYPE_PANDAS = "pandas"
+    _EXPOSED_TYPE_MODIN = "modin"
     _EXPOSED_TYPE_NUMPY = "numpy"
     _DEFAULT_EXPOSED_TYPE = _EXPOSED_TYPE_PANDAS
 
     _ALL_EXPOSED_TYPES = [
         _EXPOSED_TYPE_PANDAS,
+        _EXPOSED_TYPE_MODIN,
         _EXPOSED_TYPE_NUMPY,
     ]
     # Generic
@@ -603,7 +605,7 @@ class DataNodeConfig(Section):
             id (str): The unique identifier of the new SQL data node configuration.
             db_username (str): The database username.
             db_password (str): The database password.
-            db_name (str): The database name.
+            db_name (str): The database name, or the name of the SQLite database file.
             db_host (str): The database host. The default value is _"localhost"_.
             db_engine (str): The database engine. Possible values are _"sqlite"_, _"mssql"_, _"mysql"_, or
                 _"postgresql"_.
@@ -663,7 +665,7 @@ class DataNodeConfig(Section):
             id (str): The unique identifier of the new SQL data node configuration.
             db_username (str): The database username.
             db_password (str): The database password.
-            db_name (str): The database name.
+            db_name (str): The database name, or the name of the SQLite database file.
             db_engine (str): The database engine. Possible values are _"sqlite"_, _"mssql"_, _"mysql"_, or
                 _"postgresql"_.
             db_port (int): The database port. The default value is 1433.
