@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,17 +11,25 @@
 
 from typing import Any, Union
 
+from taipy.config.config import Config
+
 from .._repository._repository_factory import _RepositoryFactory
 from ..common._utils import _load_fct
 from ._cycle_fs_repository import _CycleFSRepository
+from ._cycle_sql_repository import _CycleSQLRepository
 
 
 class _CycleRepositoryFactory(_RepositoryFactory):
+    _REPOSITORY_MAP = {"default": _CycleFSRepository, "sql": _CycleSQLRepository}
+
     @classmethod
     def _build_repository(cls) -> Union[_CycleFSRepository, Any]:  # type: ignore
         if cls._using_enterprise():
             factory = _load_fct(
-                cls._TAIPY_ENTERPRISE_CORE_MODULE + ".cycle._cycle_repository_factory", "_CycleRepositoryFactory"
+                cls._TAIPY_ENTERPRISE_CORE_MODULE + ".cycle._cycle_repository_factory",
+                "_CycleRepositoryFactory",
             )
             return factory._build_repository()  # type: ignore
-        return _CycleFSRepository()
+        return cls._REPOSITORY_MAP.get(
+            Config.global_config.repository_type, cls._REPOSITORY_MAP.get("default")
+        )()  # type: ignore
