@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -12,15 +12,18 @@
 from collections import defaultdict
 from datetime import datetime, timedelta
 from os.path import isfile
-from typing import Any, Dict, List, Optional, Set, Tuple
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
 
+import modin.pandas as modin_pd
+import numpy as np
 import pandas as pd
 from openpyxl import load_workbook
 
 from taipy.config.common.scope import Scope
 
+from .._version._version_manager_factory import _VersionManagerFactory
 from ..common._reload import _self_reload
-from ..common.alias import DataNodeId, JobId
+from ..common.alias import DataNodeId, Edit, JobId
 from ..exceptions.exceptions import (
     ExposedTypeLengthMismatch,
     InvalidExposedType,
@@ -41,26 +44,35 @@ class ExcelDataNode(DataNode):
         scope (Scope^): The scope of this data node.
         id (str): The unique identifier of this data node.
         name (str): A user-readable name of this data node.
-        parent_id (str): The identifier of the parent (pipeline_id, scenario_id, cycle_id) or
+        owner_id (str): The identifier of the owner (pipeline_id, scenario_id, cycle_id) or
             `None`.
+        parent_ids (Optional[Set[str]]): The identifiers of the parent tasks or `None`.
         last_edit_date (datetime): The date and time of the last modification.
-        job_ids (List[str]): The ordered list of jobs that have written this data node.
-        cacheable (bool): True if this data node is cacheable. False otherwise.
-        validity_period (Optional[timedelta]): The validity period of a cacheable data node.
+        edits (List[Edit^]): The ordered list of edits for that job.
+        version (str): The string indicates the application version of the data node to instantiate. If not provided,
+            the current version is used.
+        validity_period (Optional[timedelta]): The validity period of a data node.
             Implemented as a timedelta. If _validity_period_ is set to None, the data node is
             always up-to-date.
         edit_in_progress (bool): True if a task computing the data node has been submitted
             and not completed yet. False otherwise.
         path (str): The path to the Excel file.
         properties (dict[str, Any]): A dictionary of additional properties. The _properties_
-            must have a _"default_path"_ or _"path"_ entry with the path of the Excel file.
+            must have a _"default_path"_ or _"path"_ entry with the path of the Excel file:
+
+            - _"default_path"_ `(str)`: The path of the Excel file.\n
+            - _"has_header"_ `(bool)`: If True, indicates that the Excel file has a header.\n
+            - _"sheet_name"_ `(Union[List[str], str])`: The list of sheet names to be used. This
+                can be a unique name.\n
+            - _"exposed_type"_: The exposed type of the data read from Excel file. The default value is `pandas`.\n
     """
 
     __STORAGE_TYPE = "excel"
     __EXPOSED_TYPE_PROPERTY = "exposed_type"
     __EXPOSED_TYPE_NUMPY = "numpy"
     __EXPOSED_TYPE_PANDAS = "pandas"
-    __VALID_STRING_EXPOSED_TYPES = [__EXPOSED_TYPE_PANDAS, __EXPOSED_TYPE_NUMPY]
+    __EXPOSED_TYPE_MODIN = "modin"
+    __VALID_STRING_EXPOSED_TYPES = [__EXPOSED_TYPE_PANDAS, __EXPOSED_TYPE_MODIN, __EXPOSED_TYPE_NUMPY]
     __PATH_KEY = "path"
     __DEFAULT_PATH_KEY = "default_path"
     __HAS_HEADER_PROPERTY = "has_header"
@@ -73,10 +85,11 @@ class ExcelDataNode(DataNode):
         scope: Scope,
         id: Optional[DataNodeId] = None,
         name: Optional[str] = None,
-        parent_id: Optional[str] = None,
+        owner_id: Optional[str] = None,
+        parent_ids: Optional[Set[str]] = None,
         last_edit_date: Optional[datetime] = None,
-        job_ids: List[JobId] = None,
-        cacheable: bool = False,
+        edits: List[Edit] = None,
+        version: str = None,
         validity_period: Optional[timedelta] = None,
         edit_in_progress: bool = False,
         properties: Dict = None,
@@ -107,10 +120,11 @@ class ExcelDataNode(DataNode):
             scope,
             id,
             name,
-            parent_id,
+            owner_id,
+            parent_ids,
             last_edit_date,
-            job_ids,
-            cacheable,
+            edits,
+            version or _VersionManagerFactory._build_manager()._get_latest_version(),
             validity_period,
             edit_in_progress,
             **properties,
@@ -136,7 +150,8 @@ class ExcelDataNode(DataNode):
     def _check_exposed_type(self, exposed_type):
         if isinstance(exposed_type, str) and exposed_type not in self.__VALID_STRING_EXPOSED_TYPES:
             raise InvalidExposedType(
-                f"Invalid string exposed type {exposed_type}. Supported values are {', '.join(self.__VALID_STRING_EXPOSED_TYPES)}"
+                f"Invalid string exposed type {exposed_type}. Supported values are "
+                f"{', '.join(self.__VALID_STRING_EXPOSED_TYPES)}"
             )
         elif isinstance(exposed_type, list):
             for t in exposed_type:
@@ -148,6 +163,8 @@ class ExcelDataNode(DataNode):
     def _read(self):
         if self.properties[self.__EXPOSED_TYPE_PROPERTY] == self.__EXPOSED_TYPE_PANDAS:
             return self._read_as_pandas_dataframe()
+        if self.properties[self.__EXPOSED_TYPE_PROPERTY] == self.__EXPOSED_TYPE_MODIN:
+            return self._read_as_modin_dataframe()
         if self.properties[self.__EXPOSED_TYPE_PROPERTY] == self.__EXPOSED_TYPE_NUMPY:
             return self._read_as_numpy()
         return self._read_as()
@@ -175,7 +192,8 @@ class ExcelDataNode(DataNode):
         if isinstance(exposed_type, List):
             if len(provided_sheet_names) != len(self.properties[self.__EXPOSED_TYPE_PROPERTY]):
                 raise ExposedTypeLengthMismatch(
-                    f"Expected {len(provided_sheet_names)} exposed types, got {len(self.properties[self.__EXPOSED_TYPE_PROPERTY])}"
+                    f"Expected {len(provided_sheet_names)} exposed types, got "
+                    f"{len(self.properties[self.__EXPOSED_TYPE_PROPERTY])}"
                 )
 
         for i, sheet_name in enumerate(provided_sheet_names):
@@ -198,7 +216,7 @@ class ExcelDataNode(DataNode):
             res = list()
             for row in work_sheet.rows:
                 res.append([col.value for col in row])
-            if self.properties[self.__HAS_HEADER_PROPERTY]:
+            if self.properties[self.__HAS_HEADER_PROPERTY] and res:
                 header = res.pop(0)
                 for i, row in enumerate(res):
                     res[i] = sheet_exposed_type(**dict([[h, r] for h, r in zip(header, row)]))
@@ -219,28 +237,71 @@ class ExcelDataNode(DataNode):
             return {sheet_name: df.to_numpy() for sheet_name, df in sheets.items()}
         return sheets.to_numpy()
 
-    def _read_as_pandas_dataframe(self, sheet_names=None):
+    def _read_as_pandas_dataframe(self, sheet_names=None) -> Union[Dict[Union[int, str], pd.DataFrame], pd.DataFrame]:
         if sheet_names is None:
             sheet_names = self.properties[self.__SHEET_NAME_PROPERTY]
         try:
-            kwargs = {}
+            kwargs: Dict[str, Any] = {}
             if not self.properties[self.__HAS_HEADER_PROPERTY]:
                 kwargs["header"] = None
-            return pd.read_excel(
+            df = pd.read_excel(
                 self._path,
                 sheet_name=sheet_names,
                 **kwargs,
             )
+            if isinstance(df, dict):
+                for key, value in df.items():
+                    df[key] = pd.DataFrame(value)
+                return df
+
+            return pd.DataFrame(df)
 
         except pd.errors.EmptyDataError:
             return pd.DataFrame()
 
+    def _read_as_modin_dataframe(
+        self, sheet_names=None
+    ) -> Union[Dict[Union[int, str], modin_pd.DataFrame], modin_pd.DataFrame]:
+        if sheet_names is None:
+            sheet_names = self.properties[self.__SHEET_NAME_PROPERTY]
+        try:
+            kwargs: Dict[str, Any] = {}
+            if not self.properties[self.__HAS_HEADER_PROPERTY]:
+                kwargs["header"] = None
+            if kwargs.get("header", None):
+                return modin_pd.read_excel(
+                    self._path,
+                    sheet_name=sheet_names,
+                    **kwargs,
+                )
+            else:
+                df = pd.read_excel(
+                    self._path,
+                    sheet_name=sheet_names,
+                    **kwargs,
+                )
+                if isinstance(df, dict):
+                    for key, value in df.items():
+                        df[key] = modin_pd.DataFrame(value)
+                    return df
+
+            return modin_pd.DataFrame(df)
+
+        except pd.errors.EmptyDataError:
+            return modin_pd.DataFrame()
+
     def _write(self, data: Any):
-        if isinstance(data, Dict) and all([isinstance(x, pd.DataFrame) for x in data.values()]):
-            writer = pd.ExcelWriter(self._path)
-            for key in data.keys():
-                data[key].to_excel(writer, key, index=False)
-            writer.save()
+        if isinstance(data, Dict) and all(
+            [isinstance(x, (pd.DataFrame, modin_pd.DataFrame, np.ndarray)) for x in data.values()]
+        ):
+            with pd.ExcelWriter(self._path) as writer:
+                for key in data.keys():
+                    if isinstance(data[key], np.ndarray):
+                        pd.DataFrame(data[key]).to_excel(writer, key, index=False)
+                    else:
+                        data[key].to_excel(writer, key, index=False)
+        elif isinstance(data, (pd.DataFrame, modin_pd.DataFrame)):
+            data.to_excel(self._path, index=False)
         else:
             pd.DataFrame(data).to_excel(self._path, index=False)
 
@@ -257,6 +318,4 @@ class ExcelDataNode(DataNode):
         else:
             df = pd.DataFrame(data, columns=columns)
         df.to_excel(self.path, index=False)
-        self._last_edit_date = datetime.now()
-        if job_id:
-            self.job_ids.append(job_id)
+        self._track_edit(timestamp=datetime.now(), job_id=job_id)
