@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -13,12 +13,15 @@ import os
 import pathlib
 import pickle
 from datetime import datetime, timedelta
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Set
+
+import modin.pandas as pd
 
 from taipy.config.common.scope import Scope
 
+from .._version._version_manager_factory import _VersionManagerFactory
 from ..common._reload import _self_reload
-from ..common.alias import DataNodeId, JobId
+from ..common.alias import DataNodeId, Edit
 from .data_node import DataNode
 
 
@@ -31,12 +34,14 @@ class PickleDataNode(DataNode):
         scope (Scope^): The scope of this data node.
         id (str): The unique identifier of this data node.
         name (str): A user-readable name of this data node.
-        parent_id (str): The identifier of the parent (pipeline_id, scenario_id, cycle_id) or
+        owner_id (str): The identifier of the owner (pipeline_id, scenario_id, cycle_id) or
             `None`.
+        parent_ids (Optional[Set[str]]): The identifiers of the parent tasks or `None`.
         last_edit_date (datetime): The date and time of the last modification.
-        job_ids (List[str]): The ordered list of jobs that have written this data node.
-        cacheable (bool): True if this data node is cacheable. False otherwise.
-        validity_period (Optional[timedelta]): The validity period of a cacheable data node.
+        edits (List[Edit^]): The ordered list of edits for that job.
+        version (str): The string indicates the application version of the data node to instantiate. If not provided,
+            the current version is used.
+        validity_period (Optional[timedelta]): The validity period of a data node.
             Implemented as a timedelta. If _validity_period_ is set to None, the data_node is
             always up-to-date.
         edit_in_progress (bool): True if a task computing the data node has been submitted
@@ -62,10 +67,11 @@ class PickleDataNode(DataNode):
         scope: Scope,
         id: Optional[DataNodeId] = None,
         name: Optional[str] = None,
-        parent_id: Optional[str] = None,
+        owner_id: Optional[str] = None,
+        parent_ids: Optional[Set[str]] = None,
         last_edit_date: Optional[datetime] = None,
-        job_ids: List[JobId] = None,
-        cacheable: bool = False,
+        edits: List[Edit] = None,
+        version: str = None,
         validity_period: Optional[timedelta] = None,
         edit_in_progress: bool = False,
         properties=None,
@@ -83,10 +89,11 @@ class PickleDataNode(DataNode):
             scope,
             id,
             name,
-            parent_id,
+            owner_id,
+            parent_ids,
             last_edit_date,
-            job_ids,
-            cacheable,
+            edits,
+            version or _VersionManagerFactory._build_manager()._get_latest_version(),
             validity_period,
             edit_in_progress,
             **properties,
@@ -119,13 +126,17 @@ class PickleDataNode(DataNode):
         return self._is_generated
 
     def _read(self):
-        return pickle.load(open(self._path, "rb"))
+        os.environ["MODIN_PERSISTENT_PICKLE"] = "True"
+        with open(self._path, "rb") as pf:
+            return pickle.load(pf)
 
     def _write(self, data):
-        pickle.dump(data, open(self._path, "wb"))
+        if isinstance(data, (pd.DataFrame, pd.Series)):
+            os.environ["MODIN_PERSISTENT_PICKLE"] = "True"
+        with open(self._path, "wb") as pf:
+            pickle.dump(data, pf)
 
     def __build_path(self):
-
         from taipy.config.config import Config
 
         dir_path = pathlib.Path(Config.global_config.storage_folder) / "pickles"
