@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -9,8 +9,9 @@
 # an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 # specific language governing permissions and limitations under the License.
 
+import pathlib
 from collections import defaultdict
-from typing import Any, Iterable, List, Optional
+from typing import Any, Iterable, List, Optional, Union
 
 from .._repository._repository import _AbstractRepository
 from .._repository._repository_adapter import _RepositoryAdapter
@@ -43,11 +44,13 @@ class _PipelineRepository(_AbstractRepository[_PipelineModel, Pipeline]):  # typ
                 task_datanode_edges[task_id].append(str(successor.id))
         return _PipelineModel(
             pipeline.id,
-            pipeline.parent_id,
+            pipeline.owner_id,
+            list(pipeline._parent_ids),
             pipeline.config_id,
             pipeline._properties.data,
             self.__to_task_ids(pipeline._tasks),
             _utils._fcts_to_dict(pipeline._subscribers),
+            pipeline.version,
         )
 
     def _from_model(self, model: _PipelineModel) -> Pipeline:
@@ -57,11 +60,13 @@ class _PipelineRepository(_AbstractRepository[_PipelineModel, Pipeline]):  # typ
                 model.properties,
                 model.tasks,
                 model.id,
-                model.parent_id,
+                model.owner_id,
+                set(model.parent_ids),
                 [
                     _Subscriber(_utils._load_fct(it["fct_module"], it["fct_name"]), it["fct_params"])
                     for it in model.subscribers
                 ],  # type: ignore
+                model.version,
             )
             return pipeline
         except NonExistingTask as err:
@@ -73,11 +78,11 @@ class _PipelineRepository(_AbstractRepository[_PipelineModel, Pipeline]):  # typ
     def load(self, model_id: str) -> Pipeline:
         return self.repo.load(model_id)
 
-    def _load_all(self) -> List[Pipeline]:
-        return self.repo._load_all()
+    def _load_all(self, version_number: Optional[str] = None) -> List[Pipeline]:
+        return self.repo._load_all(version_number)
 
-    def _load_all_by(self, by) -> List[Pipeline]:
-        return self.repo._load_all_by(by)
+    def _load_all_by(self, by, version_number: Optional[str] = None) -> List[Pipeline]:
+        return self.repo._load_all_by(by, version_number)
 
     def _save(self, entity: Pipeline):
         return self.repo._save(entity)
@@ -91,8 +96,14 @@ class _PipelineRepository(_AbstractRepository[_PipelineModel, Pipeline]):  # typ
     def _delete_many(self, ids: Iterable[str]):
         return self.repo._delete_many(ids)
 
-    def _search(self, attribute: str, value: Any) -> Optional[Pipeline]:
-        return self.repo._search(attribute, value)
+    def _delete_by(self, attribute: str, value: str, version_number: Optional[str] = None):
+        return self.repo._delete_by(attribute, value, version_number)
+
+    def _search(self, attribute: str, value: Any, version_number: Optional[str] = None) -> Optional[Pipeline]:
+        return self.repo._search(attribute, value, version_number)
+
+    def _export(self, entity_id: str, folder_path: Union[str, pathlib.Path]):
+        return self.repo._export(entity_id, folder_path)
 
     @staticmethod
     def __to_task_ids(tasks):
