@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,12 +11,17 @@
 
 from typing import Any, Union
 
+from taipy.config.config import Config
+
 from .._repository._repository_factory import _RepositoryFactory
 from ..common._utils import _load_fct
 from ._pipeline_fs_repository import _PipelineFSRepository
+from ._pipeline_sql_repository import _PipelineSQLRepository
 
 
 class _PipelineRepositoryFactory(_RepositoryFactory):
+    _REPOSITORY_MAP = {"default": _PipelineFSRepository, "sql": _PipelineSQLRepository}
+
     @classmethod
     def _build_repository(cls) -> Union[_PipelineFSRepository, Any]:  # type: ignore
         if cls._using_enterprise():
@@ -25,4 +30,6 @@ class _PipelineRepositoryFactory(_RepositoryFactory):
                 "_PipelineRepositoryFactory",
             )
             return factory._build_repository()  # type: ignore
-        return _PipelineFSRepository()
+        return cls._REPOSITORY_MAP.get(
+            Config.global_config.repository_type, cls._REPOSITORY_MAP.get("default")
+        )()  # type: ignore
