@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,14 +11,18 @@
 
 from typing import Type
 
-from ._scenario_manager import _ScenarioManager
 from .._manager._manager_factory import _ManagerFactory
 from ..common._utils import _load_fct
+from ._scenario_manager import _ScenarioManager
+from ._scenario_repository_factory import _ScenarioRepositoryFactory
 
 
 class _ScenarioManagerFactory(_ManagerFactory):
     @classmethod
     def _build_manager(cls) -> Type[_ScenarioManager]:  # type: ignore
         if cls._using_enterprise():
-            return _load_fct(cls._TAIPY_ENTERPRISE_CORE_MODULE + ".scenario._scenario_manager", "_ScenarioManager")  # type: ignore
+            return _load_fct(
+                cls._TAIPY_ENTERPRISE_CORE_MODULE + ".scenario._scenario_manager", "_ScenarioManager"
+            )  # type: ignore
+        _ScenarioManager._repository = _ScenarioRepositoryFactory._build_repository()  # type: ignore
         return _ScenarioManager
