@@ -1,4 +1,4 @@
-# Copyright 2022 Avaiga Private Limited
+# Copyright 2023 Avaiga Private Limited
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 # the License. You may obtain a copy of the License at
@@ -11,9 +11,10 @@
 
 from typing import Type
 
-from ._task_manager import _TaskManager
 from .._manager._manager_factory import _ManagerFactory
 from ..common._utils import _load_fct
+from ..task._task_repository_factory import _TaskRepositoryFactory
+from ._task_manager import _TaskManager
 
 
 class _TaskManagerFactory(_ManagerFactory):
@@ -21,4 +22,5 @@ class _TaskManagerFactory(_ManagerFactory):
     def _build_manager(cls) -> Type[_TaskManager]:  # type: ignore
         if cls._using_enterprise():
             return _load_fct(cls._TAIPY_ENTERPRISE_CORE_MODULE + ".task._task_manager", "_TaskManager")  # type: ignore
+        _TaskManager._repository = _TaskRepositoryFactory._build_repository()  # type: ignore
         return _TaskManager
